
%
% automatic parameterization
%

% -------------------------------

base_path = pwd;
tinker_bin_path = '"d:\program files\tinker\bin"';

a_xyz = fullfile(pwd, 'work', 'mols', 'perylene.xyz');
a_key = fullfile(pwd, 'work', 'mols', 'perylene.key');
b_xyz = fullfile(pwd, 'work', 'mols', 'perylene.xyz');
b_key = fullfile(pwd, 'work', 'mols', 'perylene.key');
hetero = 0;

simplex_iter = 200;
bfgs_iter = 50;
tol_fun = 1e-6;
tol_x = 1e-6;

% ----------------------------

temp_xyz = fullfile(pwd, 'work', 'temp', 'tempmol.xyz');
temp_key = fullfile(pwd, 'work', 'temp', 'tempmol.key');
tinker_analyzer = fullfile(tinker_bin_path, 'analyze');
tinker_minimizer = fullfile(tinker_bin_path, 'minimize');
vdw_param_file = fullfile(pwd, 'force-field', 'mm3vdw.prm');

warning('off');
% ------------
ptup = struct('E0', 0, 'x', zeros(1, 1), 'hetero', hetero, 'err', 0);
% ------------


disp(' ');
disp(' AUTOMATIC RE^2 PARAMETERIZER (pre-release), (c) 2005 Mehrtash Babadi (dt@mehrtash.info)');
disp(' ');
disp(' * Please note that you may use/redistribute this code/output freely');
disp('   by giving appropriate credit to the authors:');
disp(' ');
disp('   * M. Babadi, R. Everaers, M.R. Ejtehadi');
disp('     Coarse-grained Interaction Potentials for Anisotropic Molecules,');
disp('     Submitted to J. Chem. Phys. (arXiv index will be available soon)');

% ------------

disp(' ');
disp(' * phase 1. alignment of the molecules...');

disp(' ');
disp('   aligning the 1st molecule...');
axis_aligner(a_xyz, [a_xyz '_aligned.xyz']);
disp('   [done]');

disp(' ');
disp('   aligning the 2nd molecule...');
axis_aligner(b_xyz, [b_xyz '_aligned.xyz']);
disp('   [done]');

disp(' ');
disp(' aligning of the molecules finished succesfully!');

% ------------

disp(' ');
disp(' * phase 2. large distant interactions... ');
disp(' ');

ptup.E0 = large_dist_analyser_new(a_xyz, b_xyz, vdw_param_file);

disp(['   E0 :  ' num2str(ptup.E0)]);

% ------------

disp(' ');
disp(' * phase 3. orthogonal sample generation...');

disp(' ');
[Nsamples, A2, r2, smp_energy, mode_index, bnds] = ...
    ortho_sample_generator_new([a_xyz '_aligned.xyz'], a_key, [b_xyz '_aligned.xyz'], ...
    b_key, temp_xyz, temp_key, tinker_analyzer);

disp(' ');
disp(' * Sample generation finished successfully!');

% ------------

disp(' ');
disp(' * phase 4. parameterization (simplex)...');

% initial guess
if (hetero==0)
    x0 = zeros(7, 1);
    x0(1) = 3.0;
    x0(2) = bnds(1) + x0(1)/3;
    x0(3) = bnds(2) + x0(1)/3;
    x0(4) = bnds(3) + x0(1)/3;
    x0(5) = 0.2*x0(1)*x0(2)/(x0(3)*x0(4));
    x0(6) = 0.2*x0(1)*x0(3)/(x0(2)*x0(4));
    x0(7) = 0.2*x0(1)*x0(4)/(x0(2)*x0(3));
else
    x0 = zeros(7, 1);
    x0(1) = 4.0;
    x0(2) = bnds(1) + x0(1)/3;
    x0(3) = bnds(2) + x0(1)/3;
    x0(4) = bnds(3) + x0(1)/3;
    x0(5) = x0(1)*x0(2)/(x0(3)*x0(4));
    x0(6) = x0(1)*x0(3)/(x0(2)*x0(4));
    x0(7) = x0(1)*x0(4)/(x0(2)*x0(3));
    x0(8) = bnds(4) + x0(1)/3;
    x0(9) = bnds(5) + x0(1)/3;
    x0(10) = bnds(6) + x0(1)/3;
    x0(11) = x0(1)*x0(8)/(x0(9)*x0(10));
    x0(12) = x0(1)*x0(9)/(x0(8)*x0(10));
    x0(13) = x0(1)*x0(10)/(x0(8)*x0(9));
end;

ptup.x = x0;
disp(' * initial guess of the parameters: ');
ptup_print(ptup);

% sample well specs
orig_well_specs = ortho_well_analyser(Nsamples, A2, r2, smp_energy, mode_index);

% simplex setup
options = optimset('Display', 'iter', 'MaxFunEvals', 50000, ...
    'MaxIter', simplex_iter, 'TolFun', tol_fun, 'TolX', tol_x);

% simplex search
[ptup.x, ptup.err] = fminsearch(@well_re2_tinker_err, x0, options, ptup, orig_well_specs);

ptup_print(ptup);

% ------------

disp(' * phase 4. finalizing the parameters (bfgs)...');

options = optimset('Display', 'iter', 'MaxFunEvals', 50000, ...
    'MaxIter', bfgs_iter, 'TolFun', tol_fun, 'TolX', tol_x, 'LargeScale', 'off', ...
    'DiffMaxChange', 1e-1, 'DiffMinChange', 1e-8);

[ptup.x, ptup.err, exitflag, output, grad] = fminunc(@well_re2_tinker_err, ptup.x, options, ptup, ...
    orig_well_specs);

disp(' ');
disp(' final parameters: ');
ptup_print(ptup);
disp(' * the parameterization finished successfully! ');
disp(' ');

% ------------
