
%
% aligns the given molecule
%
% todo:
%
% - weighting
%

function [] = axis_aligner(input_xyz_path, output_xyz_path)

% constants
deg_tol = 10^-2; % tolerance in detection of degeneracy

% load original molecule
[Natoms, name, types, xyz, atomclass, n12] = load_xyz(input_xyz_path);

% giving appropriate weights to atoms
atom_weight = zeros(Natoms, 1);
atom_weight(:) = 1;

% finding the center of 'interaction'
total_weight = sum(atom_weight);
x_c = sum(atom_weight.*xyz(:,1))/total_weight;
y_c = sum(atom_weight.*xyz(:,2))/total_weight;
z_c = sum(atom_weight.*xyz(:,3))/total_weight;

% transforming to the center of 'interaction'
xyz(:,1) = xyz(:,1) - x_c;
xyz(:,2) = xyz(:,2) - y_c;
xyz(:,3) = xyz(:,3) - z_c;

% forming the inertia tensor in the current frame
m11 = sum(atom_weight.*(xyz(:,2).^2 + xyz(:,3).^2));
m22 = sum(atom_weight.*(xyz(:,1).^2 + xyz(:,3).^2));
m33 = sum(atom_weight.*(xyz(:,1).^2 + xyz(:,2).^2));
m12 = -sum(atom_weight.*xyz(:,1).*xyz(:,2));
m13 = -sum(atom_weight.*xyz(:,1).*xyz(:,3));
m23 = -sum(atom_weight.*xyz(:,2).*xyz(:,3));

L_tensor = zeros(3, 3);
L_tensor(1,1) = m11; L_tensor(1,2) = m12; L_tensor(1,3) = m13;
L_tensor(2,1) = m12; L_tensor(2,2) = m22; L_tensor(2,3) = m23;
L_tensor(3,1) = m13; L_tensor(3,2) = m23; L_tensor(3,3) = m33;

% eigen decomposition
[V_L_tensor, D_L_tensor] = eig(L_tensor); 

% rotating the atoms
rot_xyz = zeros(Natoms, 3);
rot_xyz(:,:) = (V_L_tensor'*xyz(:,:)')';

% check for degeneracy for further alignments
deg_plane = -1;
if abs((D_L_tensor(1,1)-D_L_tensor(2,2)) / ...
        (D_L_tensor(1,1)+D_L_tensor(2,2))) < deg_tol, deg_plane=1;, end;
if abs((D_L_tensor(2,2)-D_L_tensor(3,3)) / ...
        (D_L_tensor(2,2)+D_L_tensor(3,3))) < deg_tol, deg_plane=2;, end;
if abs((D_L_tensor(1,1)-D_L_tensor(3,3)) / ...
        (D_L_tensor(1,1)+D_L_tensor(3,3))) < deg_tol, deg_plane=3;, end;

% further alignment
% - rotation generators

Rx = [0    0    0
      0    0    -1
      0    1    0];
Ry = [0    0    1
      0    0    0
      -1   0    0];
Rz = [0    1    0
      -1   0    0
      0    0    0];

if deg_plane>0
    rot_mat = eye(3);
    if deg_plane==1 
        axis_a = 1;
        axis_b = 2;
        rot_mat = Rz; 
    end;
    if deg_plane==2
        axis_a = 2;
        axis_b = 3;
        rot_mat = Rx; 
    end;
    if deg_plane==3 
        axis_a = 3;
        axis_b = 1;
        rot_mat = Ry; 
    end;
    
    % optimize for best alignment
    options = optimset('Display', 'off', 'MaxFunEvals', 50000, ...
        'MaxIter', 1000, 'TolFun', 1.0e-18 , 'TolX', 1.0e-18);

    ang = fminunc(@axis_aligner_cost_func, 0, options, rot_xyz, rot_mat, ...
        axis_a, axis_b);

    [val, n_xyz] = axis_aligner_cost_func(ang, rot_xyz, rot_mat, axis_a, axis_b);
    rot_xyz = n_xyz;
    
end;

% save the rotated molecule
save_xyz(output_xyz_path, Natoms, name, types, rot_xyz, atomclass, n12);
