
%
% calculates GB VdW int. energy between two instanced of a given
% molecules
%
% changelog:
% - fixed GBsig typo in UA and UR in the original paper
% - absorbed det[S1]*det[S2] into A_{12}
%

function [vdwenergy] = get_gb_int_energy(A2, r, eps0, sigc, ...
    a1, b1, c1, ea1, eb1, ec1, a2, b2, c2, ea2, eb2, ec2, ortho_mode) 

% variables
A1 = eye(3);

A2 = A2'; % !!!!!!!!!!

E1 = [ea1   0     0
      0     eb1   0
      0     0     ec1];

E2 = [ea2   0     0
      0     eb2   0
      0     0     ec2];

%E1 = [GBsig*a1/(b1*c1)   0               0
%      0               GBsig*b1/(a1*c1)   0
%      0               0               GBsig*c1/(a1*b1)];

%E2 = [GBsig*a2/(b2*c2)   0               0
%      0               GBsig*b2/(a2*c2)   0
%      0               0               GBsig*c2/(a2*b2)];

% -----------------

S1 = [a1     0      0
      0      b1     0
      0      0      c1];

S2 = [a2     0      0
      0      b2     0
      0      0      c2];

% funny!
sig1 = (a1*b1 + c1^2)*sqrt(a1*b1);
sig2 = (a2*b2 + c2^2)*sqrt(a2*b2);

S1p2 = S1^2;
S2p2 = S2^2;

rnorm = norm(r);
rhat = r./rnorm;

A = A1' * S1p2 * A1 + A2' * S2p2 * A2;
eps12 = sqrt(2*sig1*sig2/det(A));

sig12 = 1/sqrt(2 .* rhat' * inv(A) * rhat);

B = A1' * E1 * A1 + A2' * E2 * A2;
epsp12 = 2 .* rhat' * inv(B) * rhat;

if ortho_mode==-1
    h = rnorm - sig12;
else
    h = rnorm - get_ortho_delta(ortho_mode, a1, b1, c1, a2, b2, c2);
end;

p = sigc/(h + sigc);
vdwenergy = 4 * eps0 * eps12 * epsp12^2 * (p^12 - p^6);
