
%
% MM3 (exp)
%

function [U_vdw, N_int] = get_mm3_int_energy(cr2, cA2, a_Natoms, a_atomclass, a_xyz, ...
    b_Natoms, b_atomclass, b_xyz, r_c, prm);

% transform the second mean/var structure
trans_xyz = zeros(b_Natoms,3);

% rotation
trans_xyz(:,1:3) = (cA2 * b_xyz(:,1:3)')';

% translation
trans_xyz(:,1) = trans_xyz(:,1) + cr2(1);
trans_xyz(:,2) = trans_xyz(:,2) + cr2(2);
trans_xyz(:,3) = trans_xyz(:,3) + cr2(3);

% MM3 consts
abuck = 184000.0;
bbuck = 12.0;
cbuck = 2.25;

expcut = 2.00;
expcut2 = expcut*expcut;
expmerge = (abuck*exp(-bbuck/expcut)-cbuck*expcut^6)/expcut^12;

U_vdw = 0;
r_mn = zeros(3, 1);
N_int = 0;

% double loop to find the VdW energy
for m=1:a_Natoms
    for n=1:b_Natoms
        
        r_mn(:) = trans_xyz(n,:)-a_xyz(m,:);
        norm_r_mn = norm(r_mn);
        
        if (norm_r_mn>r_c), continue;, end; % hard cutoff
        
        % parameter fetching
        type1 = a_atomclass(m); 
        type2 = b_atomclass(n);
        
        t1 = min(type1, type2);
        t2 = max(type1, type2);
        
        % lets see if a pair vdw exists
        ctr = 1;
        flag = 0;
        while 1
            if ctr>prm.Nvdw_pair, break;, end;          
            tt1 = prm.vdw_pair(ctr, 1);
            tt2 = prm.vdw_pair(ctr, 2);
            if ~(tt1==t1) || ~(tt2==t2)
                ctr = ctr + 1;
            else
                crad = prm.vdw_pair(ctr, 3);
                ceps = prm.vdw_pair(ctr, 4);
                flag = 1;
                break;
            end;          
        end;
        
        % use mixing rules
        if ~flag
            crad = prm.vdw_single(t1, 2) + prm.vdw_single(t2, 2);
            ceps = sqrt(prm.vdw_single(t1, 3)*prm.vdw_single(t2, 3));
        end;
        
        % evaluation of a single interaction
        norm2 = norm_r_mn*norm_r_mn;
        
        p2 = crad.*crad./norm2;
        p6 = p2.*p2.*p2;
        
        % switch to R^12 in lower distances when (r0/r) < 2.00
        if (p2<=expcut2)
            p = p2.^(1/2);
            expterm = abuck .* exp(-bbuck./p);
            mm3_val = ceps.*(expterm - cbuck.*p6);
        else
            p12 = p6.*p6;
            mm3_val = expmerge.*ceps.*p12;
        end;
        
        U_vdw = U_vdw + mm3_val;
        N_int = N_int + 1;
        
    end;
end;
