
%
% calculates GB VdW int. energy between two instanced of a given
% molecules
%
% changelog:
% - fixed sigma_c typo in UA and UR in the original paper
% - absorbed det[S1]*det[S2] into A_{12}, i.e. E0 = A12*det[S1]*det[S2]
%

function [vdwenergy, UA, UR, h, eta, chi] = get_gb_int_energy(A2, r, E0, sigma_c, ...
    a1, b1, c1, ea1, eb1, ec1, a2, b2, c2, ea2, eb2, ec2, ortho_mode) 

% variables
A1 = eye(3);

% the provided orientation tensors are inverses of what is applicable here
A1 = A1';
A2 = A2';

E1 = [ea1   0     0
      0     eb1   0
      0     0     ec1];

E2 = [ea2   0     0
      0     eb2   0
      0     0     ec2];

%E1 = [sigma_c*a1/(b1*c1)   0               0
%      0               sigma_c*b1/(a1*c1)   0
%      0               0               sigma_c*c1/(a1*b1)];

%E2 = [sigma_c*a2/(b2*c2)   0               0
%      0               sigma_c*b2/(a2*c2)   0
%      0               0               sigma_c*c2/(a2*b2)];

% -----------------

S1 = [a1     0      0
      0      b1     0
      0      0      c1];

S2 = [a2     0      0
      0      b2     0
      0      0      c2];

S1p2 = S1^2;
S2p2 = S2^2;
S1pm2 = inv(S1)^2;
S2pm2 = inv(S2)^2;
detS1 = det(S1);
detS2 = det(S2);

% matrix pool

rnorm = norm(r);
rhat = r./rnorm;

A1TS1p2A1 = A1'*S1p2*A1;
A2TS2p2A2 = A2'*S2p2*A2;

G = A1TS1p2A1 + A2TS2p2A2;
Ginv = inv(G);
Ginvrhat = Ginv * rhat;
sig12 = 1/sqrt(0.5 * rhat' * Ginvrhat);

A1rhat = A1 * rhat;
A2rhat = A2 * rhat;
S1pm2A1rhat = S1pm2 * A1rhat;
S2pm2A2rhat = S2pm2 * A2rhat;

sig1 = 1/sqrt(A1rhat' * S1pm2A1rhat);
sig2 = 1/sqrt(A2rhat' * S2pm2A2rhat);

H = (1/sig1) .* A1TS1p2A1 + (1/sig2) .* A2TS2p2A2;
detH = det(H);
etanum = detS1/sig1^2 + detS2/sig2^2;
etadenom = sqrt(detH/(sig1+sig2));
A1TE1A1 = A1' * E1 * A1;
A2TE2A2 = A2' * E2 * A2;
B = A1TE1A1 + A2TE2A2;
Binv = inv(B);
Binvrhat = Binv * rhat;

if ortho_mode==-1
    h = rnorm - sig12;
else
    h = rnorm - get_ortho_delta(ortho_mode, a1, b1, c1, a2, b2, c2);
end;

eta = etanum/etadenom;
chi = 2 * rhat' * Binvrhat;

% E0 = A12*det[S1]*det[S2]
r = 60^(1/3);

dnm_A = (a1+h/2)*(b1+h/2)*(c1+h/2)*(a2+h/2)*(b2+h/2)*(c2+h/2);
UA = -(E0/36)*(1+3*sigma_c*eta*chi/h)/dnm_A;

dnm_R = (a1+h/r)*(b1+h/r)*(c1+h/r)*(a2+h/r)*(b2+h/r)*(c2+h/r);
UR = (E0/2025)*(sigma_c/h)^6*(1+(45/56)*sigma_c*eta*chi/h)/dnm_R;

vdwenergy = UA + UR;
