
%
% gets interaction energy between two orientations of a given molecule
% from TINKER
%
% .xyz and TINKER .key file must be provided
%
% todo:
% --
%
% notes:
%
%  - temp .key file must be provided
%

function [int_energy] = get_tinker_int_energy(temp_xyz_path, temp_key_path, ...
    tinker_analyzer_path, a_Natoms, a_name, a_types, a_xyz, a_atomclass, a_n12, ...
    b_Natoms, b_name, b_types, b_xyz, b_atomclass, b_n12, r2, A2, ...
    a_self_energy, b_self_energy)

vdw_keyword = 'Van der Waals';

% applying the given transformations to the second molecule

% rotation
transxyz = zeros(b_Natoms,3);
transxyz(:,1:3) = (A2 * b_xyz(:,1:3)')';

% translation
transxyz(:,1) = transxyz(:,1) + r2(1);
transxyz(:,2) = transxyz(:,2) + r2(2);
transxyz(:,3) = transxyz(:,3) + r2(3);

% generating a two-molecule system

% number of atoms
newNatoms = a_Natoms + b_Natoms;

% name
new_name = [a_name ' and ' b_name];

% types
a_types_size = size(a_types,2);
b_types_size = size(b_types,2);
new_types = zeros(newNatoms, max([a_types_size; b_types_size]));
new_types(1:a_Natoms,1:a_types_size) = a_types(1:a_Natoms,1:a_types_size);
new_types(a_Natoms+1:newNatoms,1:b_types_size) = b_types(1:b_Natoms,1:b_types_size);

% xyz
new_xyz = zeros(newNatoms, 3);
new_xyz(1:a_Natoms, :) = a_xyz(1:a_Natoms, :);
new_xyz(a_Natoms+1:newNatoms, :) = transxyz(1:b_Natoms, :);

% atomclass
new_atomclass = zeros(newNatoms,1);
new_atomclass(1:a_Natoms,1) = a_atomclass(1:a_Natoms,1);
new_atomclass(a_Natoms+1:newNatoms,1) = b_atomclass(1:b_Natoms,1);

% n12
new_n12 = zeros(newNatoms,5);
new_n12(1:a_Natoms,:) = a_n12(1:a_Natoms,:);
new_n12(a_Natoms+1:newNatoms,:) = b_n12(1:b_Natoms,:);

for num=1:b_Natoms
    for k=1:4
        if ~(b_n12(num,k)==-1)
            new_n12(a_Natoms+num,k) = new_n12(a_Natoms+num,k) + a_Natoms;
        end;
    end;
end;

% creating a temporay .xyz file
save_xyz(temp_xyz_path, newNatoms, new_name, new_types, new_xyz, new_atomclass, new_n12);

% call TINKER
cmd = [tinker_analyzer_path ' ' temp_xyz_path ' E -k ' temp_key_path];
[flag, out] = system(cmd);

if flag==0
    % look for the Van der Waals term in out
    idx = findstr(vdw_keyword, out);
    substr = out(idx+size(vdw_keyword,2):end);
    res = sscanf(substr, '%f');
    energy = res(1);
else
    disp('get_tinker_int_energy: error!');
end;

int_energy = energy - a_self_energy - b_self_energy;