
%
% large distant behavior
%

function [coeff] = large_dist_analyser_new(a_xyz_path, b_xyz_path, vdw_param_file);
 
% load original molecules
[a_Natoms, a_name, a_types, a_xyz, a_atomclass, a_n12] = load_xyz(a_xyz_path);
[b_Natoms, b_name, b_types, b_xyz, b_atomclass, b_n12] = load_xyz(b_xyz_path);

% load VdW params
% radius_rule -> arithmetic
% epsilon_rule -> geometric

% MM3 consts
abuck = 184000.0;
bbuck = 12.0;
cbuck = 2.25;

% load vdw params
[Nvdw_single, vdw_single, Nvdw_pair, vdw_pair] = get_vdw_param(vdw_param_file);

% double loop over the two aggregates
coeff = 0;

for atom1=1:a_Natoms
    for atom2=1:b_Natoms
        
        type1 = a_atomclass(atom1); 
        type2 = b_atomclass(atom2);
        
        t1 = min(type1, type2);
        t2 = max(type1, type2);
        
        % lets see if a pair vdw exists
        ctr = 1;
        flag = 0;
        while 1
          if ctr>Nvdw_pair, break;, end;          
          tt1 = vdw_pair(ctr, 1);
          tt2 = vdw_pair(ctr, 2);
          if ~(tt1==t1) || ~(tt2==t2)
              ctr = ctr + 1;
          else
              crad = vdw_pair(ctr, 3);
              ceps = vdw_pair(ctr, 4);
              flag = 1;
              break;
          end;          
        end;

        % use mixing rules
        if ~flag
            crad = vdw_single(t1, 2) + vdw_single(t2, 2);
            ceps = sqrt(vdw_single(t1, 3)*vdw_single(t2, 3));
        end;
        
        coeff = coeff + ceps*crad^6;
        
    end;
end;

coeff = cbuck*coeff*9/16;
