
%
% loads an xyz file
%

function [Natoms, name, types, xyz, atomclass, n12] = load_xyz(fpath)

fid = fopen(fpath);

% header
fline = '';
while (size(fline,1)==0 & ischar(fline))
    fline = fgetl(fid);
end;

% number of atoms
[Natoms, remstr] = strtok(fline);
Natoms = str2num(Natoms);

% name
name = deblank(remstr);
name = revstr(name);
name = deblank(name);
name = revstr(name);

% type
types = zeros(Natoms,1);

% xyz
xyz = zeros(Natoms, 3);

% class
atomclass = zeros(Natoms, 1);

% 12 connectivity matrix
n12 = zeros(Natoms, 5);

while 1

    fline=fgetl(fid);
    if ~ischar(fline), break, end;
    if size(fline,1)==0, continue, end;
    
    % number
    [num, remstr] = strtok(fline);
    num=str2num(num);
    
    % type
    [atomtype, remstr] = strtok(remstr);
    dbltype = double(atomtype);
    sz=size(dbltype,2);
    types(num,1:sz)=dbltype;
    
    % xyz
    [xxx, remstr] = strtok(remstr);
    xyz(num,1)=str2num(xxx);
    [yyy, remstr] = strtok(remstr);
    xyz(num,2)=str2num(yyy);
    [zzz, remstr] = strtok(remstr);
    xyz(num,3)=str2num(zzz);
    
    % class
    [classtr, remstr] = strtok(remstr);
    atomclass(num) = str2num(classtr);
    
    % connectivity
    [n1, remstr] = strtok(remstr);
    [n2, remstr] = strtok(remstr);
    [n3, remstr] = strtok(remstr);
    [n4, remstr] = strtok(remstr);
    [n5, remstr] = strtok(remstr);
    
    if ischar(n1) n12(num,1) = str2num(n1);, else, n12(num,1)=-1;, end;
    if ischar(n2) n12(num,2) = str2num(n2);, else, n12(num,2)=-1;, end;
    if ischar(n3) n12(num,3) = str2num(n3);, else, n12(num,3)=-1;, end;
    if ischar(n4) n12(num,4) = str2num(n4);, else, n12(num,4)=-1;, end;
    if ischar(n5) n12(num,5) = str2num(n5);, else, n12(num,5)=-1;, end;

end;

fclose(fid);
