
%
% ortho modes setup
%

function [N_modes, q_rot, q_vec] = ortho_mode_setup;

% queue setup
N_modes = 18;
q_rot = zeros(N_modes, 3, 3);
q_vec = zeros(N_modes, 3);

% principal unit vectors
ex = [1; 0; 0;];
ey = [0; 1; 0;];
ez = [0; 0; 1;];

% rotation generators
Rx = [0    0    0
      0    0    -1
      0    1    0];
Ry = [0    0    1
      0    0    0
      -1   0    0];
Rz = [0   -1    0
      1    0    0
      0    0    0];

% othogonal rotations
rotx = [1    0    0
        0    0    -1
        0    1    0];
roty = [0    0    1
        0    1    0
        -1   0    0];
rotz = [0   -1    0
        1    0    0
        0    0    1];

% orthogonal orientations
rot1 = eye(3);
rot2 = rotz;
rot3 = roty;
rot4 = rotx*roty;
rot5 = rotz*rotx*roty;
rot6 = rotx'*rotz';

q_rot(1,:,:) = rot1; q_rot(2,:,:) = rot1; q_rot(3,:,:) = rot1;
q_rot(4,:,:) = rot2; q_rot(5,:,:) = rot2; q_rot(6,:,:) = rot2;
q_rot(7,:,:) = rot3; q_rot(8,:,:) = rot3; q_rot(9,:,:) = rot3;
q_rot(10,:,:) = rot4; q_rot(11,:,:) = rot4; q_rot(12,:,:) = rot4;
q_rot(13,:,:) = rot5; q_rot(14,:,:) = rot5; q_rot(15,:,:) = rot5;
q_rot(16,:,:) = rot6; q_rot(17,:,:) = rot6; q_rot(18,:,:) = rot6;

q_vec(1,:) = ex'; q_vec(2,:) = ey'; q_vec(3,:) = ez';
q_vec(4,:) = ex'; q_vec(5,:) = ey'; q_vec(6,:) = ez';
q_vec(7,:) = ex'; q_vec(8,:) = ey'; q_vec(9,:) = ez';
q_vec(10,:) = ex'; q_vec(11,:) = ey'; q_vec(12,:) = ez';
q_vec(13,:) = ex'; q_vec(14,:) = ey'; q_vec(15,:) = ez';
q_vec(16,:) = ex'; q_vec(17,:) = ey'; q_vec(18,:) = ez';
